@@ -397,7 +397,7 @@ int channel_ust_create(struct ltt_ust_session *usess,
 	/*
 	 * Invalid subbuffer size if it's lower then the page size.
 	 */
-	if (attr->attr.subbuf_size < page_size) {
+	if (attr->attr.subbuf_size < the_page_size) {
 		ret = LTTNG_ERR_INVALID;
 		goto error;
 	}
@@ -522,6 +522,13 @@ int channel_ust_disable(struct ltt_ust_session *usess,
 		DBG2("Channel UST %s already disabled", uchan->name);
 		goto end;
 	}
+
+	uchan->enabled = 0;
+
+	/*
+	 * If session is inactive we don't notify the tracer right away. We
+	 * wait for the next synchronization.
+	 */
 	if (!usess->active) {
 		goto end;
 	}
@@ -534,8 +541,6 @@ int channel_ust_disable(struct ltt_ust_session *usess,
 		goto error;
 	}
 
-	uchan->enabled = 0;
-
 	DBG2("Channel %s disabled successfully", uchan->name);
 
 	return LTTNG_OK;
