@@ -34,7 +34,7 @@ struct ltt_kernel_channel_list {
 };
 
 struct ltt_kernel_context {
-	struct lttng_kernel_context ctx;
+	struct lttng_kernel_abi_context ctx;
 	struct cds_list_head list;
 	/* Indicates whether or not the context is in a list. */
 	bool in_list;
@@ -45,13 +45,28 @@ struct ltt_kernel_event {
 	int fd;
 	int enabled;
 	enum lttng_event_type type;
-	struct lttng_kernel_event *event;
+	struct lttng_kernel_abi_event *event;
 	struct cds_list_head list;
 	char *filter_expression;
-	struct lttng_filter_bytecode *filter;
+	struct lttng_bytecode *filter;
 	struct lttng_userspace_probe_location *userspace_probe_location;
 };
 
+/* Kernel event */
+struct ltt_kernel_event_notifier_rule {
+	int fd;
+	uint64_t error_counter_index;
+	int enabled;
+	enum lttng_event_type type;
+	struct lttng_trigger *trigger;
+	uint64_t token;
+	const struct lttng_bytecode *filter;
+	struct lttng_userspace_probe_location *userspace_probe_location;
+	struct cds_lfht_node ht_node;
+	/* call_rcu delayed reclaim. */
+	struct rcu_head rcu_node;
+};
+
 /* Kernel channel */
 struct ltt_kernel_channel {
 	int fd;
@@ -132,7 +147,7 @@ struct ltt_kernel_event *trace_kernel_get_event_by_name(
 struct ltt_kernel_event *trace_kernel_find_event(
 		char *name, struct ltt_kernel_channel *channel,
 		enum lttng_event_type type,
-		struct lttng_filter_bytecode *filter);
+		struct lttng_bytecode *filter);
 struct ltt_kernel_channel *trace_kernel_get_channel_by_name(
 		const char *name, struct ltt_kernel_session *session);
 
@@ -143,15 +158,24 @@ struct ltt_kernel_session *trace_kernel_create_session(void);
 struct ltt_kernel_channel *trace_kernel_create_channel(
 		struct lttng_channel *chan);
 enum lttng_error_code trace_kernel_create_event(struct lttng_event *ev,
-		char *filter_expression, struct lttng_filter_bytecode *filter,
+		char *filter_expression, struct lttng_bytecode *filter,
 		struct ltt_kernel_event **kernel_event);
 struct ltt_kernel_metadata *trace_kernel_create_metadata(void);
 struct ltt_kernel_stream *trace_kernel_create_stream(const char *name,
 		unsigned int count);
 struct ltt_kernel_context *trace_kernel_create_context(
-		struct lttng_kernel_context *ctx);
+		struct lttng_kernel_abi_context *ctx);
+/* Trigger is only non-const to acquire a reference. */
+enum lttng_error_code trace_kernel_create_event_notifier_rule(
+		struct lttng_trigger *trigger,
+		uint64_t token,
+		uint64_t error_counter_index,
+		struct ltt_kernel_event_notifier_rule **event_notifier_rule);
 struct ltt_kernel_context *trace_kernel_copy_context(
 		struct ltt_kernel_context *ctx);
+enum lttng_error_code trace_kernel_init_event_notifier_from_event_rule(
+		const struct lttng_event_rule *rule,
+		struct lttng_kernel_abi_event_notifier *kernel_event_notifier);
 
 /*
  * Destroy functions free() the data structure and remove from linked list if
@@ -163,6 +187,7 @@ void trace_kernel_destroy_channel(struct ltt_kernel_channel *channel);
 void trace_kernel_destroy_event(struct ltt_kernel_event *event);
 void trace_kernel_destroy_stream(struct ltt_kernel_stream *stream);
 void trace_kernel_destroy_context(struct ltt_kernel_context *ctx);
+void trace_kernel_destroy_event_notifier_rule(struct ltt_kernel_event_notifier_rule *rule);
 void trace_kernel_free_session(struct ltt_kernel_session *session);
 
 #endif /* _LTT_TRACE_KERNEL_H */
