@@ -272,7 +272,7 @@ int cmd_destroy(int argc, const char **argv)
 	char *session_name = NULL;
 	const char *leftover = NULL;
 
-	struct lttng_session *sessions;
+	struct lttng_session *sessions = NULL;
 	int count;
 	int found;
 
@@ -423,6 +423,8 @@ end:
 		free(session_name);
 	}
 
+	free(sessions);
+
 	/* Overwrite ret if an error occurred during destroy_session/all */
 	ret = command_ret ? command_ret : ret;
 
