@@ -16,6 +16,7 @@
 #include <assert.h>
 
 #include <common/mi-lttng.h>
+#include <lttng/domain-internal.h>
 
 #include "../command.h"
 
@@ -155,7 +156,8 @@ static int disable_channels(char *session_name)
 
 		} else {
 			MSG("%s channel %s disabled for session %s",
-					get_domain_str(dom.type), channel_name, session_name);
+					lttng_domain_type_str(dom.type),
+					channel_name, session_name);
 			enabled = 0;
 			success = 1;
 		}
