@@ -1,18 +1,8 @@
 /*
- * Copyright (C) 2011 - David Goulet <dgoulet@efficios.com>
+ * Copyright (C) 2011 David Goulet <dgoulet@efficios.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License, version 2 only,
- * as published by the Free Software Foundation.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef _COMPAT_ENDIAN_H
@@ -20,6 +10,7 @@
 
 #if defined(__linux__) || defined(__CYGWIN__)
 #include <endian.h>
+#include <byteswap.h>
 
 /*
  * htobe/betoh are not defined for glibc <2.9, so add them
@@ -113,7 +104,11 @@
 #endif /* __USE_BSD */
 
 #elif defined(__FreeBSD__)
-#include <machine/endian.h>
+#include <sys/endian.h>
+
+#define bswap_16(x)	bswap16(x)
+#define bswap_32(x)	bswap32(x)
+#define bswap_64(x)	bswap64(x)
 
 #elif defined(__sun__)
 #include <sys/byteorder.h>
