@@ -1,33 +1,25 @@
 /*
- * Copyright (C) 2014 - Jonathan Rajotte <jonathan.r.julien@gmail.com>
- *                    - Olivier Cotte <olivier.cotte@polymtl.ca>
- * Copyright (C) 2016 - Jérémie Galarneau <jeremie.galarneau@efficios.com>
+ * Copyright (C) 2014 Jonathan Rajotte <jonathan.r.julien@gmail.com>
+ * Copyright (C) 2014 Olivier Cotte <olivier.cotte@polymtl.ca>
+ * Copyright (C) 2016 Jérémie Galarneau <jeremie.galarneau@efficios.com>
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License, version 2 only, as
- * published by the Free Software Foundation.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "lttng/tracker.h"
 #define _LGPL_SOURCE
+#include "mi-lttng.h"
 #include <common/config/session-config.h>
 #include <common/defaults.h>
-#include <lttng/snapshot-internal.h>
+#include <common/tracker.h>
 #include <lttng/channel.h>
-#include "mi-lttng.h"
+#include <lttng/snapshot-internal.h>
 
 #include <assert.h>
 
-#define MI_SCHEMA_MAJOR_VERSION 3
-#define MI_SCHEMA_MINOR_VERSION 0
+#define MI_SCHEMA_MAJOR_VERSION 4
+#define MI_SCHEMA_MINOR_VERSION 1
 
 /* Machine interface namespace URI */
 LTTNG_HIDDEN const char * const mi_lttng_xmlns = "xmlns";
@@ -47,6 +39,7 @@ LTTNG_HIDDEN const char * const mi_lttng_schema_version_value = XSTR(MI_SCHEMA_M
 const char * const mi_lttng_element_command = "command";
 const char * const mi_lttng_element_command_action = "snapshot_action";
 const char * const mi_lttng_element_command_add_context = "add-context";
+const char *const mi_lttng_element_command_add_trigger = "add-trigger";
 const char * const mi_lttng_element_command_create = "create";
 const char * const mi_lttng_element_command_destroy = "destroy";
 const char * const mi_lttng_element_command_disable_channel = "disable-channel";
@@ -54,6 +47,7 @@ const char * const mi_lttng_element_command_disable_event = "disable-event";
 const char * const mi_lttng_element_command_enable_channels = "enable-channel";
 const char * const mi_lttng_element_command_enable_event = "enable-event";
 const char * const mi_lttng_element_command_list = "list";
+const char *const mi_lttng_element_command_list_trigger = "list-trigger";
 const char * const mi_lttng_element_command_load = "load";
 LTTNG_HIDDEN const char * const mi_lttng_element_command_metadata = "metadata";
 LTTNG_HIDDEN const char * const mi_lttng_element_command_metadata_action = "metadata_action";
@@ -61,6 +55,7 @@ LTTNG_HIDDEN const char * const mi_lttng_element_command_regenerate = "regenerat
 LTTNG_HIDDEN const char * const mi_lttng_element_command_regenerate_action = "regenerate_action";
 const char * const mi_lttng_element_command_name = "name";
 const char * const mi_lttng_element_command_output = "output";
+const char *const mi_lttng_element_command_remove_trigger = "remove-trigger";
 const char * const mi_lttng_element_command_save = "save";
 const char * const mi_lttng_element_command_set_session = "set-session";
 const char * const mi_lttng_element_command_snapshot = "snapshot";
@@ -77,6 +72,7 @@ const char * const mi_lttng_element_command_version = "version";
 LTTNG_HIDDEN const char * const mi_lttng_element_command_rotate = "rotate";
 LTTNG_HIDDEN const char * const mi_lttng_element_command_enable_rotation = "enable-rotation";
 LTTNG_HIDDEN const char * const mi_lttng_element_command_disable_rotation = "disable-rotation";
+LTTNG_HIDDEN const char * const mi_lttng_element_command_clear = "clear";
 
 /* Strings related to version command */
 const char * const mi_lttng_element_version = "version";
@@ -215,6 +211,227 @@ LTTNG_HIDDEN const char * const mi_lttng_rotation_state_str_error = "ERROR";
 /* String related to enum lttng_trace_archive_location_relay_protocol_type */
 LTTNG_HIDDEN const char * const mi_lttng_rotation_location_relay_protocol_str_tcp = "TCP";
 
+/* String related to rate_policy elements */
+LTTNG_HIDDEN const char *const mi_lttng_element_rate_policy = "rate_policy";
+LTTNG_HIDDEN const char *const mi_lttng_element_rate_policy_every_n =
+		"rate_policy_every_n";
+LTTNG_HIDDEN const char *const mi_lttng_element_rate_policy_once_after_n =
+		"rate_policy_once_after_n";
+
+LTTNG_HIDDEN const char *const mi_lttng_element_rate_policy_every_n_interval =
+		"interval";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_rate_policy_once_after_n_threshold =
+				"threshold";
+
+/* String related to action elements */
+LTTNG_HIDDEN const char *const mi_lttng_element_action = "action";
+LTTNG_HIDDEN const char *const mi_lttng_element_action_list = "action_list";
+LTTNG_HIDDEN const char *const mi_lttng_element_action_notify = "action_notify";
+LTTNG_HIDDEN const char *const mi_lttng_element_action_start_session =
+		"action_start_session";
+LTTNG_HIDDEN const char *const mi_lttng_element_action_stop_session =
+		"action_stop_session";
+LTTNG_HIDDEN const char *const mi_lttng_element_action_rotate_session =
+		"action_rotate_session";
+LTTNG_HIDDEN const char *const mi_lttng_element_action_snapshot_session =
+		"action_snapshot_session";
+LTTNG_HIDDEN const char *const mi_lttng_element_action_snapshot_session_output =
+		"output";
+
+/* String related to condition */
+LTTNG_HIDDEN const char *const mi_lttng_element_condition = "condition";
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_buffer_usage_high =
+		"condition_buffer_usage_high";
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_buffer_usage_low =
+		"condition_buffer_usage_low";
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_event_rule_matches =
+		"condition_event_rule_matches";
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_session_consumed_size =
+		"condition_session_consumed_size";
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_session_rotation =
+		"condition_session_rotation";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_condition_session_rotation_completed =
+				"condition_session_rotation_completed";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_condition_session_rotation_ongoing =
+				"condition_session_rotation_ongoing";
+
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_channel_name =
+		"channel_name";
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_threshold_bytes =
+		"threshold_bytes";
+LTTNG_HIDDEN const char *const mi_lttng_element_condition_threshold_ratio =
+		"threshold_ratio";
+
+/* String related to capture descriptor */
+LTTNG_HIDDEN const char *const mi_lttng_element_capture_descriptor =
+		"capture_descriptor";
+LTTNG_HIDDEN const char *const mi_lttng_element_capture_descriptors =
+		"capture_descriptors";
+
+/* String related to event expression */
+LTTNG_HIDDEN const char *const mi_lttng_element_event_expr = "event_expr";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_expr_payload_field =
+		"event_expr_payload_field";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_expr_channel_context_field =
+		"event_expr_channel_context_field";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_event_expr_app_specific_context_field =
+				"event_expr_app_specific_context_field";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_expr_array_field_element =
+		"event_expr_array_field_element";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_expr_provider_name =
+		"provider_name";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_expr_type_name =
+		"type_name";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_expr_index = "index";
+
+/* String related to event rule */
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule = "event_rule";
+
+/* String related to lttng_event_rule_type */
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_event_name =
+		"event_name";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_name_pattern =
+		"name_pattern";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_filter_expression =
+		"filter_expression";
+
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_jul_logging =
+		"event_rule_jul_logging";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_kernel_kprobe =
+		"event_rule_kernel_kprobe";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_kernel_syscall =
+		"event_rule_kernel_syscall";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_kernel_tracepoint =
+		"event_rule_kernel_tracepoint";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_kernel_uprobe =
+		"event_rule_kernel_uprobe";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_log4j_logging =
+		"event_rule_log4j_logging";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_python_logging =
+		"event_rule_python_logging";
+LTTNG_HIDDEN const char *const mi_lttng_element_event_rule_user_tracepoint =
+		"event_rule_user_tracepoint";
+
+/* String related to lttng_event_rule_kernel_syscall. */
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_event_rule_kernel_syscall_emission_site =
+				"emission_site";
+
+/* String related to enum lttng_event_rule_kernel_syscall_emission_site. */
+LTTNG_HIDDEN const char *const
+		mi_lttng_event_rule_kernel_syscall_emission_site_entry_exit =
+				"entry+exit";
+LTTNG_HIDDEN const char
+		*const mi_lttng_event_rule_kernel_syscall_emission_site_entry =
+				"entry";
+LTTNG_HIDDEN const char *const
+		mi_lttng_event_rule_kernel_syscall_emission_site_exit = "exit";
+
+/* String related to lttng_event_rule_user_tracepoint */
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_event_rule_user_tracepoint_name_pattern_exclusions =
+				"name_pattern_exclusions";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_event_rule_user_tracepoint_name_pattern_exclusion =
+				"name_pattern_exclusion";
+
+/* String related to log level rule. */
+LTTNG_HIDDEN const char *const mi_lttng_element_log_level_rule =
+		"log_level_rule";
+LTTNG_HIDDEN const char *const mi_lttng_element_log_level_rule_exactly =
+		"log_level_rule_exactly";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_log_level_rule_at_least_as_severe_as =
+				"log_level_rule_at_least_as_severe_as";
+LTTNG_HIDDEN const char *const mi_lttng_element_log_level_rule_level = "level";
+
+/* String related to kernel probe location. */
+LTTNG_HIDDEN const char *const mi_lttng_element_kernel_probe_location =
+		"kernel_probe_location";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_kernel_probe_location_symbol_offset =
+				"kernel_probe_location_symbol_offset";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_kernel_probe_location_symbol_offset_name =
+				"name";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_kernel_probe_location_symbol_offset_offset =
+				"offset";
+
+LTTNG_HIDDEN const char *const mi_lttng_element_kernel_probe_location_address =
+		"kernel_probe_location_address";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_kernel_probe_location_address_address =
+				"address";
+
+/* String related to userspace probe location. */
+LTTNG_HIDDEN const char *const mi_lttng_element_userspace_probe_location =
+		"userspace_probe_location";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_userspace_probe_location_binary_path =
+				"binary_path";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_userspace_probe_location_function =
+				"userspace_probe_location_function";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_userspace_probe_location_function_name =
+				"name";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_userspace_probe_location_lookup_method =
+				"userspace_probe_location_lookup_method";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_userspace_probe_location_lookup_method_function_default =
+				"userspace_probe_location_lookup_method_function_default";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_userspace_probe_location_lookup_method_function_elf =
+				"userspace_probe_location_lookup_method_function_elf";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_userspace_probe_location_lookup_method_tracepoint_sdt =
+				"userspace_probe_location_lookup_method_tracepoint_sdt";
+LTTNG_HIDDEN const char
+		*const mi_lttng_element_userspace_probe_location_tracepoint =
+				"userspace_probe_location_tracepoint";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_userspace_probe_location_tracepoint_probe_name =
+				"probe_name";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_userspace_probe_location_tracepoint_provider_name =
+				"provider_name";
+
+/* String related to enum
+ * lttng_userspace_probe_location_function_instrumentation_type */
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_userspace_probe_location_function_instrumentation_type =
+				"instrumentation_type";
+LTTNG_HIDDEN const char *const
+		mi_lttng_userspace_probe_location_function_instrumentation_type_entry =
+				"ENTRY";
+
+/* String related to trigger */
+LTTNG_HIDDEN const char *const mi_lttng_element_triggers = "triggers";
+LTTNG_HIDDEN const char *const mi_lttng_element_trigger = "trigger";
+LTTNG_HIDDEN const char *const mi_lttng_element_trigger_owner_uid = "owner_uid";
+
+/* String related to error_query. */
+LTTNG_HIDDEN const char *const mi_lttng_element_error_query_result =
+		"error_query_result";
+LTTNG_HIDDEN const char *const mi_lttng_element_error_query_result_counter =
+		"error_query_result_counter";
+LTTNG_HIDDEN const char *const
+		mi_lttng_element_error_query_result_counter_value = "value";
+LTTNG_HIDDEN const char *const mi_lttng_element_error_query_result_description =
+		"description";
+LTTNG_HIDDEN const char *const mi_lttng_element_error_query_result_name =
+		"name";
+LTTNG_HIDDEN const char *const mi_lttng_element_error_query_result_type =
+		"type";
+LTTNG_HIDDEN const char *const mi_lttng_element_error_query_results =
+		"error_query_results";
+
 /* String related to add-context command */
 LTTNG_HIDDEN const char * const mi_lttng_element_context_symbol = "symbol";
 
@@ -363,7 +580,7 @@ const char *mi_lttng_logleveltype_string(enum lttng_loglevel_type value)
 	}
 }
 
-LTTNG_HIDDEN
+static
 const char *mi_lttng_eventtype_string(enum lttng_event_type value)
 {
 	switch (value) {
@@ -428,6 +645,46 @@ const char *mi_lttng_event_contexttype_string(enum lttng_event_context_type val)
 		return config_event_context_callstack_user;
 	case LTTNG_EVENT_CONTEXT_CALLSTACK_KERNEL:
 		return config_event_context_callstack_kernel;
+	case LTTNG_EVENT_CONTEXT_CGROUP_NS:
+		return config_event_context_cgroup_ns;
+	case LTTNG_EVENT_CONTEXT_IPC_NS:
+		return config_event_context_ipc_ns;
+	case LTTNG_EVENT_CONTEXT_MNT_NS:
+		return config_event_context_mnt_ns;
+	case LTTNG_EVENT_CONTEXT_NET_NS:
+		return config_event_context_net_ns;
+	case LTTNG_EVENT_CONTEXT_PID_NS:
+		return config_event_context_pid_ns;
+	case LTTNG_EVENT_CONTEXT_TIME_NS:
+		return config_event_context_time_ns;
+	case LTTNG_EVENT_CONTEXT_USER_NS:
+		return config_event_context_user_ns;
+	case LTTNG_EVENT_CONTEXT_UTS_NS:
+		return config_event_context_uts_ns;
+	case LTTNG_EVENT_CONTEXT_UID:
+		return config_event_context_uid;
+	case LTTNG_EVENT_CONTEXT_EUID:
+		return config_event_context_euid;
+	case LTTNG_EVENT_CONTEXT_SUID:
+		return config_event_context_suid;
+	case LTTNG_EVENT_CONTEXT_GID:
+		return config_event_context_gid;
+	case LTTNG_EVENT_CONTEXT_EGID:
+		return config_event_context_egid;
+	case LTTNG_EVENT_CONTEXT_SGID:
+		return config_event_context_sgid;
+	case LTTNG_EVENT_CONTEXT_VUID:
+		return config_event_context_vuid;
+	case LTTNG_EVENT_CONTEXT_VEUID:
+		return config_event_context_veuid;
+	case LTTNG_EVENT_CONTEXT_VSUID:
+		return config_event_context_vsuid;
+	case LTTNG_EVENT_CONTEXT_VGID:
+		return config_event_context_vgid;
+	case LTTNG_EVENT_CONTEXT_VEGID:
+		return config_event_context_vegid;
+	case LTTNG_EVENT_CONTEXT_VSGID:
+		return config_event_context_vsgid;
 	default:
 		return NULL;
 	}
@@ -453,7 +710,6 @@ const char *mi_lttng_eventfieldtype_string(enum lttng_event_field_type val)
 LTTNG_HIDDEN
 const char *mi_lttng_domaintype_string(enum lttng_domain_type value)
 {
-	/* Note: This is a *duplicate* of get_domain_str from bin/lttng/utils.c */
 	switch (value) {
 	case LTTNG_DOMAIN_KERNEL:
 		return config_domain_type_kernel;
@@ -516,7 +772,7 @@ const char *mi_lttng_trace_archive_location_relay_protocol_type_string(
 	case LTTNG_TRACE_ARCHIVE_LOCATION_RELAY_PROTOCOL_TYPE_TCP:
 		return mi_lttng_rotation_location_relay_protocol_str_tcp;
 	default:
-		/* Should not have an unknow relay protocol. */
+		/* Should not have an unknown relay protocol. */
 		assert(0);
 		return NULL;
 	}
@@ -688,6 +944,15 @@ int mi_lttng_writer_write_element_string(struct mi_writer *writer,
 			element_name, value);
 }
 
+LTTNG_HIDDEN
+int mi_lttng_writer_write_element_double(struct mi_writer *writer,
+		const char *element_name,
+		double value)
+{
+	return config_writer_write_element_double(
+			writer->writer, element_name, value);
+}
+
 LTTNG_HIDDEN
 int mi_lttng_version(struct mi_writer *writer, struct mi_lttng_version *version,
 	const char *lttng_description, const char *lttng_license)
@@ -1275,7 +1540,7 @@ end:
 	return ret;
 }
 
-LTTNG_HIDDEN
+static
 int mi_lttng_event_userspace_probe(struct mi_writer *writer,
 		struct lttng_event *event)
 {
@@ -1498,22 +1763,80 @@ end:
 LTTNG_HIDDEN
 int mi_lttng_trackers_open(struct mi_writer *writer)
 {
-	return mi_lttng_writer_open_element(writer, config_element_trackers);
+	return mi_lttng_writer_open_element(
+			writer, config_element_process_attr_trackers);
+}
+
+static int get_tracker_elements(enum lttng_process_attr process_attr,
+		const char **element_process_attr_tracker,
+		const char **element_process_attr_value)
+{
+	int ret = 0;
+
+	switch (process_attr) {
+	case LTTNG_PROCESS_ATTR_PROCESS_ID:
+		*element_process_attr_tracker =
+				config_element_process_attr_tracker_pid;
+		*element_process_attr_value =
+				config_element_process_attr_pid_value;
+		break;
+	case LTTNG_PROCESS_ATTR_VIRTUAL_PROCESS_ID:
+		*element_process_attr_tracker =
+				config_element_process_attr_tracker_vpid;
+		*element_process_attr_value =
+				config_element_process_attr_vpid_value;
+		break;
+	case LTTNG_PROCESS_ATTR_USER_ID:
+		*element_process_attr_tracker =
+				config_element_process_attr_tracker_uid;
+		*element_process_attr_value =
+				config_element_process_attr_uid_value;
+		break;
+	case LTTNG_PROCESS_ATTR_VIRTUAL_USER_ID:
+		*element_process_attr_tracker =
+				config_element_process_attr_tracker_vuid;
+		*element_process_attr_value =
+				config_element_process_attr_vuid_value;
+		break;
+	case LTTNG_PROCESS_ATTR_GROUP_ID:
+		*element_process_attr_tracker =
+				config_element_process_attr_tracker_gid;
+		*element_process_attr_value =
+				config_element_process_attr_gid_value;
+		break;
+	case LTTNG_PROCESS_ATTR_VIRTUAL_GROUP_ID:
+		*element_process_attr_tracker =
+				config_element_process_attr_tracker_vgid;
+		*element_process_attr_value =
+				config_element_process_attr_vgid_value;
+		break;
+	default:
+		ret = LTTNG_ERR_SAVE_IO_FAIL;
+	}
+	return ret;
 }
 
 LTTNG_HIDDEN
-int mi_lttng_pid_tracker_open(struct mi_writer *writer)
+int mi_lttng_process_attribute_tracker_open(
+		struct mi_writer *writer, enum lttng_process_attr process_attr)
 {
 	int ret;
+	const char *element_tracker, *element_value;
 
-	/* Open element pid_tracker */
-	ret = mi_lttng_writer_open_element(writer, config_element_pid_tracker);
+	ret = get_tracker_elements(
+			process_attr, &element_tracker, &element_value);
+	if (ret) {
+		return ret;
+	}
+
+	/* Open process attribute tracker element */
+	ret = mi_lttng_writer_open_element(writer, element_tracker);
 	if (ret) {
 		goto end;
 	}
 
-	/* Open targets element */
-	ret = mi_lttng_targets_open(writer);
+	/* Open values element */
+	ret = mi_lttng_process_attr_values_open(writer);
 end:
 	return ret;
 }
@@ -1529,7 +1852,9 @@ int mi_lttng_pids_open(struct mi_writer *writer)
  * mi api bump. The use of process element break the mi api.
  */
 LTTNG_HIDDEN
-int mi_lttng_pid(struct mi_writer *writer, pid_t pid , const char *name,
+int mi_lttng_pid(struct mi_writer *writer,
+		pid_t pid,
+		const char *name,
 		int is_open)
 {
 	int ret;
@@ -1566,35 +1891,136 @@ end:
 }
 
 LTTNG_HIDDEN
-int mi_lttng_targets_open(struct mi_writer *writer)
+int mi_lttng_process_attr_values_open(struct mi_writer *writer)
 {
-	return mi_lttng_writer_open_element(writer,
-			config_element_targets);
+	return mi_lttng_writer_open_element(
+			writer, config_element_process_attr_values);
 }
 
 LTTNG_HIDDEN
-int mi_lttng_pid_target(struct mi_writer *writer, pid_t pid, int is_open)
+int mi_lttng_all_process_attribute_value(struct mi_writer *writer,
+		enum lttng_process_attr process_attr,
+		bool is_open)
 {
 	int ret;
+	const char *element_id_tracker, *element_target_id;
 
-	ret = mi_lttng_writer_open_element(writer,
-			config_element_target_pid);
+	ret = get_tracker_elements(
+			process_attr, &element_id_tracker, &element_target_id);
+	if (ret) {
+		return ret;
+	}
+
+	ret = mi_lttng_writer_open_element(writer, element_target_id);
 	if (ret) {
 		goto end;
 	}
 
-	/* Writing pid number
-	 * Special case for element all on track untrack command
-	 * All pid is represented as wildcard *
-	 */
-	if ((int) pid == -1) {
-		ret = mi_lttng_writer_write_element_string(writer,
-				config_element_pid,
-				mi_lttng_element_track_untrack_all_wildcard);
-	} else {
-		ret = mi_lttng_writer_write_element_signed_int(writer,
-				config_element_pid, (int) pid);
+	ret = mi_lttng_writer_open_element(writer, config_element_type);
+	if (ret) {
+		goto end;
 	}
+
+	ret = mi_lttng_writer_write_element_bool(writer, config_element_all, 1);
+	if (ret) {
+		goto end;
+	}
+
+	ret = mi_lttng_writer_close_element(writer);
+	if (ret) {
+		goto end;
+	}
+
+	if (!is_open) {
+		ret = mi_lttng_writer_close_element(writer);
+		if (ret) {
+			goto end;
+		}
+	}
+end:
+	return ret;
+}
+
+LTTNG_HIDDEN
+int mi_lttng_integral_process_attribute_value(struct mi_writer *writer,
+		enum lttng_process_attr process_attr,
+		int64_t value,
+		bool is_open)
+{
+	int ret;
+	const char *element_id_tracker, *element_target_id;
+
+	ret = get_tracker_elements(
+			process_attr, &element_id_tracker, &element_target_id);
+	if (ret) {
+		return ret;
+	}
+
+	ret = mi_lttng_writer_open_element(writer, element_target_id);
+	if (ret) {
+		goto end;
+	}
+
+	ret = mi_lttng_writer_open_element(writer, config_element_type);
+	if (ret) {
+		goto end;
+	}
+
+	ret = mi_lttng_writer_write_element_signed_int(
+			writer, config_element_process_attr_id, value);
+	if (ret) {
+		goto end;
+	}
+
+	ret = mi_lttng_writer_close_element(writer);
+	if (ret) {
+		goto end;
+	}
+
+	if (!is_open) {
+		ret = mi_lttng_writer_close_element(writer);
+		if (ret) {
+			goto end;
+		}
+	}
+
+end:
+	return ret;
+}
+
+LTTNG_HIDDEN
+int mi_lttng_string_process_attribute_value(struct mi_writer *writer,
+		enum lttng_process_attr process_attr,
+		const char *value,
+		bool is_open)
+
+{
+	int ret;
+	const char *element_id_tracker, *element_target_id;
+
+	ret = get_tracker_elements(
+			process_attr, &element_id_tracker, &element_target_id);
+	if (ret) {
+		return ret;
+	}
+
+	ret = mi_lttng_writer_open_element(writer, element_target_id);
+	if (ret) {
+		goto end;
+	}
+
+	ret = mi_lttng_writer_open_element(writer, config_element_type);
+	if (ret) {
+		goto end;
+	}
+
+	ret = mi_lttng_writer_write_element_string(
+			writer, config_element_name, value);
+	if (ret) {
+		goto end;
+	}
+
+	ret = mi_lttng_writer_close_element(writer);
 	if (ret) {
 		goto end;
 	}
@@ -1833,7 +2259,7 @@ end:
 
 LTTNG_HIDDEN
 int mi_lttng_snapshot_list_output(struct mi_writer *writer,
-		struct lttng_snapshot_output *output)
+		const struct lttng_snapshot_output *output)
 {
 	int ret;
 
@@ -2056,13 +2482,13 @@ int mi_lttng_rotation_schedule(struct mi_writer *writer,
 		status = lttng_rotation_schedule_periodic_get_period(schedule,
 				&value);
 		element_name = mi_lttng_element_rotation_schedule_periodic;
-	        value_name = mi_lttng_element_rotation_schedule_periodic_time_us;
+		value_name = mi_lttng_element_rotation_schedule_periodic_time_us;
 		break;
 	case LTTNG_ROTATION_SCHEDULE_TYPE_SIZE_THRESHOLD:
 		status = lttng_rotation_schedule_size_threshold_get_threshold(
 				schedule, &value);
 		element_name = mi_lttng_element_rotation_schedule_size_threshold;
-	        value_name = mi_lttng_element_rotation_schedule_size_threshold_bytes;
+		value_name = mi_lttng_element_rotation_schedule_size_threshold_bytes;
 		break;
 	default:
 		ret = -1;
@@ -2137,7 +2563,7 @@ int mi_lttng_rotation_schedule_result(struct mi_writer *writer,
 	}
 
 	/* Close rotation_schedule_result element */
-        ret = mi_lttng_writer_close_element(writer);
+	ret = mi_lttng_writer_close_element(writer);
 	if (ret) {
 		goto end;
 	}
