@@ -1,18 +1,7 @@
 /*
- * Copyright (C) 2019 - Jérémie Galarneau <jeremie.galarneau@efficios.com>
+ * Copyright (C) 2019 Jérémie Galarneau <jeremie.galarneau@efficios.com>
  *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License, version 2.1 only,
- * as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
- * for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this library; if not, write to the Free Software Foundation,
- * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+ * SPDX-License-Identifier: GPL-2.0-only
  */
 
 #include <lttng/session-descriptor-internal.h>
@@ -627,12 +616,12 @@ ssize_t lttng_session_descriptor_create_from_buffer(
 
 	current_view = lttng_buffer_view_from_view(payload, offset,
 			sizeof(*base_header));
-	base_header = (typeof(base_header)) current_view.data;
-	if (!base_header) {
+	if (!lttng_buffer_view_is_valid(&current_view)) {
 		ret = -1;
 		goto end;
 	}
 
+	base_header = (typeof(base_header)) current_view.data;
 	switch (base_header->type) {
 	case LTTNG_SESSION_DESCRIPTOR_TYPE_REGULAR:
 	case LTTNG_SESSION_DESCRIPTOR_TYPE_SNAPSHOT:
@@ -643,12 +632,12 @@ ssize_t lttng_session_descriptor_create_from_buffer(
 
 		current_view = lttng_buffer_view_from_view(payload, offset,
 				sizeof(*live_header));
-		live_header = (typeof(live_header)) current_view.data;
-		if (!live_header) {
+		if (!lttng_buffer_view_is_valid(&current_view)) {
 			ret = -1;
 			goto end;
 		}
 
+		live_header = (typeof(live_header)) current_view.data;
 		live_timer_us = live_header->live_timer_us;
 		break;
 	}
@@ -685,12 +674,12 @@ ssize_t lttng_session_descriptor_create_from_buffer(
 	/* Map the name. */
 	current_view = lttng_buffer_view_from_view(payload, offset,
 			base_header->name_len);
-	name = current_view.data;
-	if (!name) {
+	if (!lttng_buffer_view_is_valid(&current_view)) {
 		ret = -1;
 		goto end;
 	}
 
+	name = current_view.data;
 	if (base_header->name_len == 1 ||
 			name[base_header->name_len - 1] ||
 			strlen(name) != base_header->name_len - 1) {
@@ -716,11 +705,12 @@ skip_name:
 		/* Map a URI. */
 		current_view = lttng_buffer_view_from_view(payload,
 				offset, sizeof(*uri));
-		uri = (typeof(uri)) current_view.data;
-		if (!uri) {
+		if (!lttng_buffer_view_is_valid(&current_view)) {
 			ret = -1;
 			goto end;
 		}
+
+		uri = (typeof(uri)) current_view.data;
 		uris[i] = zmalloc(sizeof(*uri));
 		if (!uris[i]) {
 			ret = -1;
