@@ -1,18 +1,8 @@
 /*
- * Copyright (C) 2012 - David Goulet <dgoulet@efficios.com>
+ * Copyright (C) 2012 David Goulet <dgoulet@efficios.com>
  *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License, version 2 only, as
- * published by the Free Software Foundation.
+ * SPDX-License-Identifier: GPL-2.0-only
  *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 51
- * Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #define _LGPL_SOURCE
@@ -61,7 +51,7 @@ static const struct uri_proto proto_uri[] = {
  * Return pointer to the character in s matching one of the characters in
  * accept. If nothing is found, return pointer to the end of string (eos).
  */
-static const inline char *strpbrk_or_eos(const char *s, const char *accept)
+static inline const char *strpbrk_or_eos(const char *s, const char *accept)
 {
 	char *p = strpbrk(s, accept);
 	if (p == NULL) {
@@ -136,7 +126,7 @@ static int set_ip_address(const char *addr, int af, char *dst, size_t size)
 			 * We choose to use the system name resolution API first
 			 * to honor its network configuration. If this fails, we
 			 * resolve to the appropriate loopback address. This is
-			 * done to accomodate systems which may want to start
+			 * done to accommodates systems which may want to start
 			 * tracing before their network configured.
 			 */
 			const char *loopback_addr = af == AF_INET ?
@@ -266,22 +256,6 @@ void uri_free(struct lttng_uri *uri)
 	free(uri);
 }
 
-/*
- * Return an allocated URI.
- */
-LTTNG_HIDDEN
-struct lttng_uri *uri_create(void)
-{
-	struct lttng_uri *uri;
-
-	uri = zmalloc(sizeof(struct lttng_uri));
-	if (uri == NULL) {
-		PERROR("zmalloc uri");
-	}
-
-	return uri;
-}
-
 /*
  * Parses a string URI to a lttng_uri. This function can potentially return
  * more than one URI in uris so the size of the array is returned and uris is
@@ -540,6 +514,7 @@ end:
 	free(addr_f);
 
 	*uris = tmp_uris;
+	assert(size == 1 || size == 2);
 	return size;
 
 free_error:
@@ -560,7 +535,7 @@ ssize_t uri_parse_str_urls(const char *ctrl_url, const char *data_url,
 	unsigned int equal = 1, idx = 0;
 	/* Add the "file://" size to the URL maximum size */
 	char url[PATH_MAX + 7];
-	ssize_t size_ctrl = 0, size_data = 0, size;
+	ssize_t ctrl_uri_count = 0, data_uri_count = 0, uri_count;
 	struct lttng_uri *ctrl_uris = NULL, *data_uris = NULL;
 	struct lttng_uri *tmp_uris = NULL;
 
@@ -597,12 +572,15 @@ ssize_t uri_parse_str_urls(const char *ctrl_url, const char *data_url,
 
 	/* Parse the control URL if there is one */
 	if (ctrl_url && *ctrl_url != '\0') {
-		size_ctrl = uri_parse(ctrl_url, &ctrl_uris);
-		if (size_ctrl < 1) {
+		ctrl_uri_count = uri_parse(ctrl_url, &ctrl_uris);
+		if (ctrl_uri_count < 1) {
 			ERR("Unable to parse the URL %s", ctrl_url);
 			goto parse_error;
 		}
 
+		/* 1 and 2 are the only expected values on success. */
+		assert(ctrl_uri_count == 1 || ctrl_uri_count == 2);
+
 		/* At this point, we know there is at least one URI in the array */
 		set_default_uri_attr(&ctrl_uris[0], LTTNG_STREAM_CONTROL);
 
@@ -613,7 +591,7 @@ ssize_t uri_parse_str_urls(const char *ctrl_url, const char *data_url,
 		}
 
 		/* URL are not equal but the control URL uses a net:// protocol */
-		if (size_ctrl == 2) {
+		if (ctrl_uri_count == 2) {
 			if (!equal) {
 				ERR("Control URL uses the net:// protocol and the data URL is "
 						"different. Not allowed.");
@@ -633,13 +611,16 @@ ssize_t uri_parse_str_urls(const char *ctrl_url, const char *data_url,
 		int ret;
 
 		/* We have to parse the data URL in this case */
-		size_data = uri_parse(data_url, &data_uris);
-		if (size_data < 1) {
+		data_uri_count = uri_parse(data_url, &data_uris);
+		if (data_uri_count < 1) {
 			ERR("Unable to parse the URL %s", data_url);
 			goto error;
-		} else if (size_data == 2) {
+		} else if (data_uri_count == 2) {
 			ERR("Data URL can not be set with the net[4|6]:// protocol");
 			goto error;
+		} else {
+			/* 1 and 2 are the only expected values on success. */
+			assert(data_uri_count == 1);
 		}
 
 		set_default_uri_attr(&data_uris[0], LTTNG_STREAM_DATA);
@@ -653,10 +634,13 @@ ssize_t uri_parse_str_urls(const char *ctrl_url, const char *data_url,
 		}
 	}
 
-	/* Compute total size */
-	size = size_ctrl + size_data;
+	/* Compute total size. */
+	uri_count = ctrl_uri_count + data_uri_count;
+	if (uri_count <= 0) {
+		goto error;
+	}
 
-	tmp_uris = zmalloc(sizeof(struct lttng_uri) * size);
+	tmp_uris = zmalloc(sizeof(struct lttng_uri) * uri_count);
 	if (tmp_uris == NULL) {
 		PERROR("zmalloc uris");
 		goto error;
@@ -664,7 +648,7 @@ ssize_t uri_parse_str_urls(const char *ctrl_url, const char *data_url,
 
 	if (ctrl_uris) {
 		/* It's possible the control URIs array contains more than one URI */
-		memcpy(tmp_uris, ctrl_uris, sizeof(struct lttng_uri) * size_ctrl);
+		memcpy(tmp_uris, ctrl_uris, sizeof(struct lttng_uri) * ctrl_uri_count);
 		++idx;
 		free(ctrl_uris);
 	}
@@ -676,7 +660,7 @@ ssize_t uri_parse_str_urls(const char *ctrl_url, const char *data_url,
 
 	*uris = tmp_uris;
 
-	return size;
+	return uri_count;
 
 error:
 	free(ctrl_uris);
